.. JSON API Client documentation master file, created by
   sphinx-quickstart on Thu Mar  2 15:35:36 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to JSON API Client's documentation!
===========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage
   classes

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


